
Strumento DoS multithread in Python che inonda i server Minecraft Java con pacchetti di handshake contraffatti, riutilizzo delle connessioni, padding del payload e spoofing della versione del protocollo.
JAVAFLOOD è uno strumento progettato per sferrare attacchi di Denial of Service (DoS) contro server Minecraft Java Edition. Questo strumento inonda il server con molteplici metodi per sovraccaricare le risorse del server, causandone uno stato di non responsività.
Qualsiasi uso non autorizzato, inclusi i tentativi di interrompere, sovraccaricare o danneggiare i server, è severamente proibito e può essere considerato illegale ai sensi delle leggi applicabili. Tali azioni possono comportare gravi conseguenze sia per i sistemi presi di mira sia per gli individui coinvolti.
Si prega di utilizzare questo strumento responsabilmente e solo per legittimi test di sicurezza e scopi accademici. L'uso improprio di questo strumento è eticamente scorretto, potenzialmente illegale e fortemente sconsigliato.
Lo sviluppatore di questo strumento lo ha creato esclusivamente per scopi educativi e di ricerca all'interno di un ambiente controllato e non si assume alcuna responsabilità per qualsiasi uso improprio, danno o conseguenza legale derivante da un uso intenzionale o non autorizzato da parte di terzi.
Inondazione di handshake TCP:
handshake TCP per consumare le risorse dei socket del server.Riutilizzo delle connessioni:
connessione TCP per massimizzare l'impatto.Multithreading:
ThreadPoolExecutor per eseguire più thread per l'invio parallelo di pacchetti.Sincronizzazione dei thread:
thread daemonAbuso del protocollo Minecraft:
Padding del payload:
Cicli rapidi di connessione-disconnessione:
Spoofing della versione del protocollo:
Verifica dello stato del server:
python3 javaflood.py -api < IP/Domain >| Argomento | Obbligatorio | Descrizione |
|---|---|---|
| -ip | Sì | Definisce l'indirizzo IP del server di destinazione (ad es., 127.0.0.1). |
| -port | Sì | Specifica la porta di destinazione (deve essere un intero tra 1 e 65535). |
| -s | Sì | Configura la dimensione (in byte) di ciascun pacchetto trasmesso. |
| -t | Sì | Determina il numero di thread di esecuzione paralleli. |
| -p | Sì | Imposta la versione del protocollo da utilizzare durante l'esecuzione. |
| -d | Sì | Controlla il tempo totale di esecuzione (in secondi). |
| -api | Opzionale | Richiama la funzione API di mcstatus con il dominio. |
| -load | Opzionale | Carica una configurazione esterna da un percorso di file JSON specificato. |
| -wait | Opzionale | Ritarda l'esecuzione di un numero specificato di secondi. |
| -art | Opzionale | Attiva/disattiva la visibilità del logo (1 = mostra, 0 = nascondi). |
| -h | No | Mostra questo messaggio di aiuto ed esce. |
Clona questo repository sulla tua macchina locale:
git clone https://github.com/Audrise/javaflood.git
cd javaflood
Installa le librerie Python necessarie:
pip3 install -r requirements.txt
Esegui javaflood utilizzando diversi metodi come di seguito:
python3 javaflood.py -ip 120.0.0.1 -port 25565 -s 100 -t 100 -p 47 -d 60 -wait 10 -art 0
oppure puoi usare il parametro -load:
python3 javaflood.py -load config.json
Utilizzando il parametro -load, puoi eseguire direttamente lo strumento con la configurazione impostata all'interno di un file .json, senza la necessità di inserire manualmente tutti i parametri. Questo è particolarmente utile per velocizzare il processo di configurazione ed eseguire lo strumento con impostazioni preconfigurate.
python3 javaflood.py -load config.json
Questo caricherà tutti i parametri da config.json ed eseguirà lo strumento.
Assicurati che il file .json che crei sia formattato correttamente, con i parametri attesi dallo strumento. Ecco un esempio di una struttura JSON valida per questo strumento:
{
"ip": "127.0.0.1",
"port": 25565,
"packet_size": 0,
"threads": 0,
"protocol": 0,
"duration": 0,
"wait": 60,
"art": 0
}